@@ -1,16 +1,17 @@
 #Copyright ReportLab Europe Ltd. 2000-2018
 #see license.txt for license details
 __doc__="""The Reportlab PDF generation library."""
-Version = "3.5.32"
+Version = "3.5.56"
 __version__=Version
-__date__='20191024'
+__date__='20201201'
 
 import sys, os
 
-if sys.version_info[0:2]!=(2, 7) and sys.version_info<(3, 5):
-    raise ImportError("""reportlab requires Python 2.7+ or 3.5+; 3.0-3.4 are not supported.
+__min_python_version__ = (3,6)
+if sys.version_info[0:2]!=(2, 7) and sys.version_info< __min_python_version__:
+    raise ImportError("""reportlab requires Python 2.7+ or %s.%s+; other versions are unsupported.
 If you want to try with other python versions edit line 10 of reportlab/__init__
-to remove this error.""")
+to remove this error.""" % (__min_python_version__))
 
 #define these early in reportlab's life
 isPy3 = sys.version_info[0]==3
